==> openshift-model-operator-5.1.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class ConsoleFluentImpl<A extends ConsoleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConsoleFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ConsoleSpecBuilder spec;
    private ConsoleStatusBuilder status;

    public ConsoleFluentImpl() {
    }

    public ConsoleFluentImpl(Console instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public ConsoleFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public ConsoleFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public ConsoleFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public ConsoleFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ConsoleFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ConsoleSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public ConsoleSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ConsoleSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new ConsoleSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public ConsoleFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public ConsoleFluent.SpecNested<A> withNewSpecLike(ConsoleSpec item) {
        return new SpecNestedImpl(item);
    }

    public ConsoleFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public ConsoleFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new ConsoleSpecBuilder().build());
    }

    public ConsoleFluent.SpecNested<A> editOrNewSpecLike(ConsoleSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ConsoleStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public ConsoleStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(ConsoleStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new ConsoleStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public ConsoleFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public ConsoleFluent.StatusNested<A> withNewStatusLike(ConsoleStatus item) {
        return new StatusNestedImpl(item);
    }

    public ConsoleFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public ConsoleFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new ConsoleStatusBuilder().build());
    }

    public ConsoleFluent.StatusNested<A> editOrNewStatusLike(ConsoleStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ConsoleFluentImpl that = (ConsoleFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ConsoleFluent.MetadataNested<N>> implements ConsoleFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends ConsoleSpecFluentImpl<ConsoleFluent.SpecNested<N>> implements ConsoleFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ConsoleSpecBuilder builder;

            SpecNestedImpl(ConsoleSpec item) {
                this.builder = new ConsoleSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new ConsoleSpecBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends ConsoleStatusFluentImpl<ConsoleFluent.StatusNested<N>> implements ConsoleFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ConsoleStatusBuilder builder;

            StatusNestedImpl(ConsoleStatus item) {
                this.builder = new ConsoleStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new ConsoleStatusBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}

==> openshift-model-operator-5.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class ConsoleFluentImpl<A extends ConsoleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConsoleFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ConsoleSpecBuilder spec;
    private ConsoleStatusBuilder status;

    public ConsoleFluentImpl() {
    }

    public ConsoleFluentImpl(Console instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ConsoleSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public ConsoleSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ConsoleSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new ConsoleSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<A> withNewSpecLike(ConsoleSpec item) {
        return new SpecNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new ConsoleSpecBuilder().build());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<A> editOrNewSpecLike(ConsoleSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ConsoleStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public ConsoleStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(ConsoleStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new ConsoleStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<A> withNewStatusLike(ConsoleStatus item) {
        return new StatusNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new ConsoleStatusBuilder().build());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<A> editOrNewStatusLike(ConsoleStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ConsoleFluentImpl that = (ConsoleFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends ConsoleSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ConsoleSpecBuilder builder;

            SpecNestedImpl(ConsoleSpec item) {
                this.builder = new ConsoleSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new ConsoleSpecBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends ConsoleStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ConsoleFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ConsoleStatusBuilder builder;

            StatusNestedImpl(ConsoleStatus item) {
                this.builder = new ConsoleStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new ConsoleStatusBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}
